@@ -2,13 +2,14 @@ package Module::Functions;
 use strict;
 use warnings;
 use 5.008005;
-our $VERSION = '2.0.0';
+our $VERSION = '2.1.0';
 
 use parent qw/Exporter/;
 
 use Sub::Identify ();
 
 our @EXPORT = qw(get_public_functions);
+our @EXPORT_OK = qw(get_full_functions);
 
 sub get_public_functions {
     my $klass = shift || caller(0);
@@ -24,6 +25,12 @@ sub get_public_functions {
     return @functions;
 }
 
+sub get_full_functions {
+    my $klass = shift || caller(0);
+    no strict 'refs';
+    return keys %{"${klass}::"};
+}
+
 1;
 __END__
 
@@ -47,11 +54,9 @@ It is useful to create a exportable function list.
 
 =head1 METHODS
 
-=over 4
+=head2 my @functions = get_public_functions()
 
-=item my @functions = get_public_functions()
-
-=item my @functions = get_public_functions($package)
+=head2 my @functions = get_public_functions($package)
 
 Get a public function list from the package.
 
@@ -67,11 +72,9 @@ For example:
 
 In this case, return value of C<< get_public_functions('Foo') >> does not contain 'catfile'. Return value is C<< ('foo') >>.
 
-=back
+=head3 RULES
 
-=head1 RULES
-
-This module remove some function names.
+This C<< get_public_functions >> removes some function names.
 
 Rules are here:
 
@@ -85,6 +88,15 @@ Rules are here:
 
 =back
 
+=head2 my @functions = get_full_functions();
+
+=head2 my @functions = get_full_functions($package)
+
+This function get ALL functions.
+ALL means functions that were imported from other packages.
+And included specially named functions(BEGIN , UNITCHECK , CHECK , INIT and END).
+Of course, included also private functions( ex. _foo ).
+
 =head1 AUTHOR
 
 Tokuhiro Matsuno E<lt>tokuhirom AAJKLFJEF@ GMAIL COME<gt>
